| FLXMRhyreg | R Documentation |
Function used in flexmix M-Step to estimate hybrid model
FLXMRhyreg(
formula = . ~ .,
family = c("hyreg"),
type = NULL,
type_cont = NULL,
type_dich = NULL,
variables_both = NULL,
variables_cont = NULL,
variables_dich = NULL,
stv = NULL,
offset = NULL,
opt_method = "BFGS",
optimizer = "optim",
lower = -Inf,
upper = Inf,
...
)
formula |
linear model |
family |
default |
type |
|
type_cont |
value of |
type_dich |
value of |
variables_both |
|
variables_cont |
|
variables_dich |
character vactor; variables to be fitted only on dichotomous data. see Details of hyreg2 |
stv |
|
offset |
offset as in |
opt_method |
|
optimizer |
|
lower |
lower bound for censored data. If this is used, |
upper |
upper bound for censored data. If this is used, |
... |
additional arguments for |
a model object, that can be used in hyreg2 as input for parameter model in flexmix::flexmix()
a model object, that can be used in hyreg2 as input for parameter model in flexmix::flexmix
Svenja Elkenkamp and Kim Rand
formula <- y ~ -1 + x1 + x2 + x3
the$k <- 2
stv <- setNames(c(0.2,0,1,1,1),c(colnames(simulated_data_norm)[3:5],c("sigma","theta")))
x <- model.matrix(formula,simulated_data_norm)
y <- simulated_data_norm$y
w <- 1
model <- FLXMRhyreg(formula = formula,
family=c("hyreg"),
type = simulated_data_norm$type,
stv = stv,
type_cont = "TTO",
type_dich = "DCE_A",
opt_method = "L-BFGS-B",
control = list(iter.max = 1000, verbose = 4),
offset = NULL,
optimizer = "optim",
variables_both = names(stv)[!is.element(names(stv),c("sigma","theta"))],
variables_cont = NULL,
variables_dich = NULL,
lower = -Inf,
upper = Inf,
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.