| get_stv | R Documentation |
function to export coefficient values and names from a model fitted with hyreg2 or hyreg2_het
These values can be used as stv for a new model with k > 1
get_stv(mod, comp = "Comp.1")
mod |
|
comp |
|
named vector of parameter estimates from mod. Can be used as stv for additional model estimations using
hyreg2 or hyreg2_het
Svenja Elkenkamp
formula <- y ~ -1 + x1 + x2 + x3 | id
k <- 1
stv <- setNames(c(0.2,0,1,1,1),c(colnames(simulated_data_norm)[3:5],c("sigma","theta")))
control = list(iter.max = 1000, verbose = 4)
rm(counter)
mod <- hyreg2(formula = formula,
data = simulated_data_norm,
type = simulated_data_norm$type,
stv = stv,
k = k,
type_cont = "TTO",
type_dich = "DCE_A",
opt_method = "L-BFGS-B",
control = control,
latent = "both",
id_col = "id"
)
new_stv <- get_stv(mod)
# these new_stv can be used in an other estimation using hyreg2 as stv
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.